<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>nuovo</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Ogni turno</numerusform>
            <numerusform>Ogni %1 turni</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Modifica armi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Schema armi non valido</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Modifica schemi</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 è stato rimosso dalla tua lista ignorati</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 è stato aggiunto alla tua lista ignorati</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 è stato rimosso dalla tua lista amici</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 è stato aggiunto alla tua lista amici</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Impossibile avviare il server</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Impossibile salvare il record al file %1</translation>
    </message>
    <message>
        <source>new</source>
        <translation>nuovo</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Inserisci il record dalla lista sottostante</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>it.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Impossibile aprire file demo %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temi</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tutte</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Piccola</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Caverna</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Stramba</translation>
    </message>
    <message>
        <source>Tunnel size</source>
        <translation type="obsolete">Grandezza Tunnel</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tipo</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Host non trovato. Controllare impostazioni di nome host e porta.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Connessione rifiutata</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Quit reason:</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Stanza distrutta</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Sei stato espulso</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation>Il nickname %1 è
registrato su Hedgewars.org
Per favore inserisci la tua password
o scegli un altro nickname:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 è entrato nella stanza</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 è entrato</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 ha lasciato (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 se ne è andato</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf ha ritornato un errore durante il rendering del testo, probabilmente relativo ad un bug in freetype2. Si raccomanda di aggiornare le proprie librerie freetype.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Messaggio del server:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Inserisci messaggio</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Pulisci la cache degli account</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Connessione in corso...</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzato</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Il premio per il miglior colpo è stato vinto da &lt;b&gt;%1&lt;/b&gt; , con &lt;b&gt;%2&lt;/b&gt; punti.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Il miglior killer è &lt;b&gt;%1&lt;/b&gt; con &lt;b&gt;%2&lt;/b&gt; uccisione in un turno.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Il miglior killer è &lt;b&gt;%1&lt;/b&gt; con &lt;b&gt;%2&lt;/b&gt; uccisioni in un turno.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Durante questo round è stato ucciso &lt;b&gt;%1&lt;/b&gt; hedgehog in totale.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Un totale di &lt;b&gt;%1&lt;/b&gt; hedgehogs sono stati uccisi durante questo round.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Gioco locale (Gioca una partita su un singolo computer)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Gioco in rete (Gioca una partita attraverso la rete)</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Gioca</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Seleziona il server dalla lista sottostante</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Controllo</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Gioco in LAN</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Server ufficiale</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nuova squadra</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Modifica squadra</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Elimina team</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation>Nuovo schema armi</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation>Modifica schema armi</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation>Elimina schema armi</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Inserisci il nome file:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Impossibile rinominarlo in</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Impossibile cancellare il file</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Seleziona un record dalla lista</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Entra</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Opzioni amministratore</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Nome stanza:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Questa partita è nella lobby.
Puoi entrare e iniziare a giocare quando la partita inizia.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Questa partita è in corso.
Puoi entrare come spettatore ma dovrai aspettare la fine della partita per giocare.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 è l&apos;host. Può modificare le impostazioni e far partire il gioco.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Mappa casuale</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Le partite possono essere giocate su mappe statiche o casuali.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Lo Schema di Gioco definisce le opzioni generali e le preferenze come Tempo di Round, Sudden Death o Vampirismo.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Lo Schema delle Armi definisce le armi disponibili le loro munizioni.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>E&apos; presente %1 utente connesso a questa stanza.</numerusform>
            <numerusform>Sono presenti %1 utenti connessi a questa stanza.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>E&apos; presente %1 squadra partecipante in questa stanza.</numerusform>
            <numerusform>Sono presenti %1 squadre partecipanti in questa stanza.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Inserisci il nome della stanza</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Seleziona la stanza dalla lista</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Labirinto Casuale</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Enable random mines</source>
        <translation>Abilita mine casuali</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Guadagna l&apos;80% del danno che fai in salute</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Condividi il danno causato al nemico</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>I tuoi ricci non possono muoversi, metti le tue abilità d&apos;artigliere alla prova</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Casuale</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Secondi</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Difendi il tuo fortino e distruggi i nemici, due colori di squadra al massimo!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Le squadre inizieranno in lati opposti del terreno, due colori di squadra al massimo!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Il terreno non può essere distrutto!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Aggiungi un bordo indistruttibile intorno al terreno</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Gravità zero</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Mirino facilitato con laser</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Tutti i ricci hanno un personale campo di forza</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>L&apos;ordine di gioco è casuale invece che nell&apos;ordine della stanza.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Gioca con un Re. Se il Re muore la tua squadra perderà.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Piazza a turno i tuoi ricci prima dell&apos;inizio della partita.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Le munizioni sono condivise tra tutti i team che hanno lo stesso colore.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Disabilita le travi nella generazione di mappe casuali.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Partita singola ( Una partita veloce contro il computer, con le impostazioni scelte da te)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Multigiocatore (Gioca contro i tuoi amici, o squadre di AI)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Modalità Allenamento (Allena le tue abilità in una gamma di missioni). IN SVILUPPO</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demo (Guarda le partite registrate)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Carica (Carica una partita precedentemente salvata)</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Kick</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Gioca</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Limita le entrate</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Limita l&apos;aggiunta di nuove squadre</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Ban</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Segui</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Aggiungi amico</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Togli ignora</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Rimuovi amico</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Abilita il suono</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Mostra FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Mostra danno in maniera alternativa</translation>
    </message>
    <message>
        <source>Check for updates at startup</source>
        <translation>Controlla aggiornamenti all&apos;avvio</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Abilita musica</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Frontend schermo intero</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Concatena data e ora di registrazione al nome file</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation>Qualità ridotta</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Mostra suggerimenti nel menu armi</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Abilita suoni nel frontend</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Abilita la musica nel frontend</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Effetti nel frontend</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>Mappa generata...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Umano</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Livello</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Default di sistema)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>labirinto generato...</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Missione</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Membri della squadra</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Associazione dei tasti</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Fortino</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Squadre</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Opzioni Audio/Grafica</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armi</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Gioco in rete</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Squadre in gioco</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Modificatori di gioco</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Impostazioni di base</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Impostazioni dei Team</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Varie</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Timeout delle mine</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Mine</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Questo programma è distribuito sotto licenza GNUGeneral Public License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Sviluppatori:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafica:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Traduzioni:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Ringraziamenti speciali:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armi</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Limite FPS</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Nickname di rete</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Nome del server:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Porta del server:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Suoni:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Volume sonoro iniziale</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Modificatore di danno</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Durata del turno</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Salute iniziale</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Timeout del sudden death</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Nome dello schema:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Caduta Casse</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Schema di gioco</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% Mine Difettose</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Tomba</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Bandiera</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voce</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Locale</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Riavvia il gioco per applicare</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Questa versione SVN è &apos;work in progress&apos; e può non essere compatibile con le altre versioni del gioco.
Alcune feature potrebbero essere incomplete o non funzionanti. Usatela a vostro rischio!</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Esplosivi</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>senza nome</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Connessione con il server persa</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Impossibile aprire la directory:
%1
Controllare la propria installazione</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armi</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>Non è possibile modificare il set di armi predefinito</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>Non è possibile eliminare il set di armi predefinito</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Vuoi davvero eliminare questo set di armi?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Impossibile creare la directory %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nickname</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Per favore inserisci il tuo nickname</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation>Gioca!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Avvia server</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connetti</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Specifica</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Gioca</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Visualizza demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carica</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Team Casuale</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Nome Stanza</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Creata da</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Regole</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armi</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Set delle armi</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Probabilità</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Munizioni nelle casse</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Ritardi</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Impossibile avviare il server: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Impossibile eseguire il motore: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampirismo</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Artiglieria</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Modalità fortino</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Dividi le squadre</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Terreno solido</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Aggiungi bordo</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Gravità zero</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Vista laser</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Invulnerabilità</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation>Aggiungi mine</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Ordine Casuale</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Re</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Posiziona Ricci</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Munizioni Condivise</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Disabilita Travi</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>su</translation>
    </message>
    <message>
        <source>left</source>
        <translation>sinistra</translation>
    </message>
    <message>
        <source>right</source>
        <translation>destra</translation>
    </message>
    <message>
        <source>down</source>
        <translation>giù</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>attacca</translation>
    </message>
    <message>
        <source>put</source>
        <translation>usa</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>cambia</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>trova hedgehog</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>menu delle armi</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>timer 1 sec</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>timer 2 sec</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>timer 3 sec</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>timer 4 sec</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>timer 5 sec</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pausa</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>abbassare volume</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>alzare volume</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>cambiare modalità</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>cattura</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>informazioni
hedgehogs</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>esci</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>chat</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>cronologia chat</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>conferma</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>mirino di precisione</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>zoom in</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>zoom out</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>reset zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>salto lungo</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>salto alto</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Controlli di base</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Controlli per le armi</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Controlli camera e cursore</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Muovi i tuoi ricci e punta:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Scavalca buchi e ostacoli saltando:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Spara con l&apos;arma selezionata o usa l&apos;attrezzo:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Raccogli un&apos;arma o mira con il cursore:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Cambia il riccio attualmente attivo (se possibile):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Scegli un&apos;arma o uno strumento:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Imposta il timer su bombe e armi a tempo:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Muovi la camera verso il riccio attivo:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Muovi il cursore o la camera senza usare il mouse:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Modifica il livello di zoom:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Parla al tuo team o a tutti i partecipanti:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pausa, continua o lascia il gioco:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Modifica il volume del gioco in esecuzione:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Modalità schermo intero:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Fai uno screenshot:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Cambia le etichette sui ricci:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Assi</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Su)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Giù)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Cappello</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Sinistra)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Destra)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>(Pulsante)</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>(Tastiera)</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Mouse: Tasto sinistro</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Mouse: Tasto centrale</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Mouse: Tasto destro</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Mouse: Scroll in su</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Mouse: Scroll in giù</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Invio</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Spazio</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Invio</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Uguale</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Su</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Giù</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina su</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina giu</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Shift destro</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Shift sinistro</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Ctrl destro</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Ctrl sinistro</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Alt destro</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Alt sinistro</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Meta destro</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Meta sinistro</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>Tasto A</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>Tasto B</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>Tasto X</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Tasto X</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>Tasto LB</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>Tasto RB</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Tasto indietro</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Tasto start</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Leva sinistra</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Leva destra</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Leva sinistra (Destra)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Leva sinistra (Sinistra)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Leva sinistra (Giu)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Leva sinistra (Su)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Grilletto sinistro</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Grilletto destro</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Leva destra (Giu)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Leva destra (Su)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Leva destra (Destra)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Leva destra (Sinistra)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
</context>
</TS>
